@@ -8,7 +8,7 @@ __all__ = ('TroveAPI', 'TroveError',
 __author__ = 'Nick Vlku <n =at= yourtrove.com>'
 __status__ = "Beta"
 __dependencies__ = ('python-dateutil', 'simplejson', 'urllib', 'urllib2', 'oauth')
-__version__ = '0.1'
+__version__ = '0.1.2'
 
 # This code is lovingly crafted in Brooklyn, NY (40°42′51″N, 73°57′12″W)
 #
@@ -94,7 +94,6 @@ class TroveAPI():
         self._default_oauth_params = {
                   'oauth_consumer_key': self._Consumer.key,
                   'oauth_signature_method': 'PLAINTEXT',
-                  'oauth_timestamp': str(int(time.time())),
                   'oauth_nonce':  _generate_nonce(),
                   'oauth_version': _oauth_version(),
                   'scope': ','.join(self._scope)
@@ -114,6 +113,8 @@ class TroveAPI():
     def get_default_oauth_params(self):
         parameters = self._default_oauth_params.copy()
         parameters['oauth_nonce'] = _generate_nonce()
+        parameters['oauth_timestamp'] = str(int(time.time()))
+
         return parameters
     
     def __make_oauth_request(self, url, parameters=None, oauth_signature=None, token=None, signed=False, method="POST"):
